==> cohesity_management_sdk-1.1.6.tar.gz: cohesity_management_sdk-1.1.6/cohesity_management_sdk/models/environment_search_objects_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class EnvironmentSearchObjectsEnum(object):

    """Implementation of the 'environment_SearchObjects' enum.

    TODO: type enum description here.

    Attributes:
        KVMWARE: TODO: type description here.
        KHYPERV: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KAZURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KAGENT: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KISILON: TODO: type description here.
        KKVM: TODO: type description here.
        KAWS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGCP: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KVCD: TODO: type description here.
        KO365: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KGCPNATIVE: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    K_HYPERV = 'kHyperV'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KAZURE = 'kAzure'

    KNETAPP = 'kNetapp'

    KAGENT = 'kAgent'

    KGENERICNAS = 'kGenericNas'

    KACROPOLIS = 'kAcropolis'

    KPHYSICALFILES = 'kPhysicalFiles'

    KISILON = 'kIsilon'

    KKVM = 'kKVM'

    KAWS = 'kAWS'

    KEXCHANGE = 'kExchange'

    K_HYPERV_VSS = 'kHyperVVSS'

    KORACLE = 'kOracle'

    KGCP = 'kGCP'

    KFLASHBLADE = 'kFlashBlade'

    KAWSNATIVE = 'kAWSNative'

    KVCD = 'kVCD'

    KO365 = 'kO365'

    KO365OUTLOOK = 'kO365Outlook'

    KHYPERFLEX = 'kHyperFlex'

    KGCPNATIVE = 'kGCPNative'

==> cohesity_management_sdk-1.5.0.tar.gz: cohesity_management_sdk-1.5.0/cohesity_management_sdk/models/environment_search_objects_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class EnvironmentSearchObjectsEnum(object):

    """Implementation of the 'environment_SearchObjects' enum.

    TODO: type enum description here.

    Attributes:
        KVMWARE: TODO: type description here.
        KHYPERV: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KAZURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KAGENT: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KISILON: TODO: type description here.
        KGPFS: TODO: type description here.
        KKVM: TODO: type description here.
        KAWS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGCP: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KVCD: TODO: type description here.
        KO365: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KGCPNATIVE: TODO: type description here.
        KKUBERNETES: TODO: type description here.
        KELASTIFILE: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    K_HYPERV = 'kHyperV'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KAZURE = 'kAzure'

    KNETAPP = 'kNetapp'

    KAGENT = 'kAgent'

    KGENERICNAS = 'kGenericNas'

    KACROPOLIS = 'kAcropolis'

    KPHYSICALFILES = 'kPhysicalFiles'

    KISILON = 'kIsilon'

    KGPFS = 'kGPFS'

    KKVM = 'kKVM'

    KAWS = 'kAWS'

    KEXCHANGE = 'kExchange'

    K_HYPERV_VSS = 'kHyperVVSS'

    KORACLE = 'kOracle'

    KGCP = 'kGCP'

    KFLASHBLADE = 'kFlashBlade'

    KAWSNATIVE = 'kAWSNative'

    KVCD = 'kVCD'

    KO365 = 'kO365'

    KO365OUTLOOK = 'kO365Outlook'

    KHYPERFLEX = 'kHyperFlex'

    KGCPNATIVE = 'kGCPNative'

    KKUBERNETES = 'kKubernetes'

    KELASTIFILE = 'kElastifile'
